from loganmatic import Calculator

minha_calculadora = Calculator()
# Execute all methods
print("Absolute Value:", Calculator.absoluteValue(-5))
print("Factorial:", Calculator.factorial(5))
print("Square Root:", Calculator.squareRoot(16))
print("Cubic Root:", Calculator.cubicRoot(27))
print("Factor:", Calculator.factor(100))
print("Sine:", Calculator.sine(0.5))
print("Cosine:", Calculator.cosine(0.5))
print("Random Number:", Calculator.random_number_between(1, 10))
print("Root of First Degree:", Calculator.root_of_first_degree(2, 4))
print("Root of Second Degree:", Calculator.root_of_second_degree(1, -3, 2))
print("Euler Number:", start_calculator.EulerNumber)
print("Pi:", start_calculator.Pi)
